.. image:: https://travis-ci.org/MacHu-GWU/fileshelf-project.svg?branch=master
    :target: https://travis-ci.org/MacHu-GWU/fileshelf-project?branch=master

.. image:: https://codecov.io/gh/MacHu-GWU/fileshelf-project/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/MacHu-GWU/fileshelf-project

.. image:: https://img.shields.io/pypi/v/fileshelf.svg
    :target: https://pypi.python.org/pypi/fileshelf

.. image:: https://img.shields.io/pypi/l/fileshelf.svg
    :target: https://pypi.python.org/pypi/fileshelf

.. image:: https://img.shields.io/pypi/pyversions/fileshelf.svg
    :target: https://pypi.python.org/pypi/fileshelf

.. image:: https://img.shields.io/badge/Star_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/fileshelf-project


Welcome to ``fileshelf`` Documentation
==============================================================================

A web app to organize and search your file in your own way.


Quick Links
------------------------------------------------------------------------------

- .. image:: https://img.shields.io/badge/Link-Document-red.svg
      :target: http://www.wbh-doc.com.s3.amazonaws.com/fileshelf/index.html

- .. image:: https://img.shields.io/badge/Link-API_Reference_and_Source_Code-red.svg
      :target: http://www.wbh-doc.com.s3.amazonaws.com/fileshelf/py-modindex.html

- .. image:: https://img.shields.io/badge/Link-Install-red.svg
      :target: `install`_

- .. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
      :target: https://github.com/MacHu-GWU/fileshelf-project

- .. image:: https://img.shields.io/badge/Link-Submit_Issue_and_Feature_Request-blue.svg
      :target: https://github.com/MacHu-GWU/fileshelf-project/issues

- .. image:: https://img.shields.io/badge/Link-Download-blue.svg
      :target: https://pypi.python.org/pypi/fileshelf#downloads


.. _install:

Install
------------------------------------------------------------------------------

``fileshelf`` is released on PyPI, so all you need is:

.. code-block:: console

    $ pip install fileshelf

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade fileshelf